@@ -7,26 +7,34 @@
 
 """Marshmallow fields."""
 
+from .babel import BabelGettextDictField, FormatDate, FormatDatetime, \
+    FormatEDTF, FormatTime
 from .contrib import Function, Method
 from .edtfdatestring import EDTFDateString
 from .generated import GenFunction, GenMethod
+from .identifier import IdentifierSet
 from .isodate import ISODateString
 from .isolanguage import ISOLangString
 from .links import Link, Links
-from .localized_edtfdatestring import LocalizedEDTFDateString
 from .nestedattr import NestedAttribute
 from .sanitizedhtml import ALLOWED_HTML_ATTRS, ALLOWED_HTML_TAGS, SanitizedHTML
 from .sanitizedunicode import SanitizedUnicode
+from .strippedhtml import StrippedHTML
 from .trimmed import TrimmedString
 
 __all__ = (
     'ALLOWED_HTML_ATTRS',
     'ALLOWED_HTML_TAGS',
+    'BabelGettextDictField',
     'EDTFDateString',
+    'FormatDate',
+    'FormatDatetime',
+    'FormatEDTF',
+    'FormatTime',
     'Function',
-    'LocalizedEDTFDateString',
     'GenFunction',
     'GenMethod',
+    'IdentifierSet',
     'ISODateString',
     'ISOLangString',
     'Link',
@@ -35,5 +43,6 @@ __all__ = (
     'NestedAttribute',
     'SanitizedHTML',
     'SanitizedUnicode',
+    'StrippedHTML',
     'TrimmedString',
 )
